import { AxiosError } from 'axios'
import { useQuery as useRQ, UseQueryOptions } from 'react-query'

import { Pattern } from 'src/models'
import axiosService from 'src/services/axios-service'

export namespace GetPatternsQuery {
  export type Params = {}

  export type Response = Pattern[]

  export const key = ['patterns']

  export const getKey = (params: Params) => [...key, params]

  export const queryFn = (_params: Params) =>
    axiosService.get<Response>(`/patterns/`).then((res) => res.data)

  export const useQuery = <Select = Response>(
    params: Params,
    options: UseQueryOptions<Response, AxiosError, Select> = {}
  ) => {
    return useRQ(getKey(params), () => queryFn(params), {
      ...options,
    })
  }
}
